/** @typedef SerializerHandler */
declare class JsonSerializerAdapter {
    constructor(jsonSerializerCore: any);
    /**
     * Returns an object that contains the serializers added to JsonSerializer
     * object. The keys are obtained from serializer.getSerializerType method and
     * the values are the Serializer objects.
     *
     * @returns {object} Object that contains the serializers added to
     *   JsonSerializer object.
     */
    getSerializers(): object;
    /**
     * Adds serializers through the serializersInstaller and to update the
     * JsonSerializer object.
     *
     * @param {object} serializersInstaller An object that adds serializers using
     *   the install method.
     * @param {(
     *   serializerHandler: {
     *     getSerializers: () => object
     *     addSerializer: (serializer: object) => void
     *   },
     *   installOptions: object,
     * ) => void} serializersInstaller.install
     *   The method used to add serializers to JsonSerializer object.
     * @param {object} [installOptions] An object that contains the install
     *   options.
     */
    installSerializersAndRefreshJsonSerializer(serializersInstaller: {
        install: (serializerHandler: {
            getSerializers: () => object;
            addSerializer: (serializer: object) => void;
        }, installOptions: object) => void;
    }, installOptions?: object): void;
    /**
     * Adds a Serializer and to update the JsonSerializer object.
     *
     * @param {object} serializer An object used to serialize and unserialize
     *   data.
     * @param {() => string} serializer.getSerializerType An function that returns
     *   the type of serializer.
     * @param {(unserializedData: any) => object} serializer.serialize An function
     *   that serializes data.
     * @param {(serializedData: string) => any} serializer.parse An function that
     *   unserializes data.
     */
    addSerializerAndRefreshJsonSerializer(serializer: {
        getSerializerType: () => string;
        serialize: (unserializedData: any) => object;
        parse: (serializedData: string) => any;
    }): void;
    /**
     * Serializes the data.
     *
     * @param {any} value The data to serialize.
     * @param {object} options The serialize options used by the
     *   jsonSerializer.serialize method.
     * @param {string | number} [options.space] Adds indentation, white space, and
     *   line break characters to the return-value JSON text to make it easier to
     *   read.
     * @returns {string} JSON string that contains the serialized data.
     */
    serialize(value: any, options?: {
        space?: string | number;
    }): string;
    /**
     * Unserializes the data serialized by serialize method.
     *
     * @param {string} value The data to unserialize.
     * @param {object} options The parse options used by the jsonSerializer.parse
     *   method.
     * @returns {any} The unserialized data.
     */
    parse(value: string, options?: object): any;
    #private;
}

/**
 * Creates a new instance of JsonSerializerAdapter.
 *
 * @param {object} options The options used to configure the installer created
 *   by json-serializer-base-serializers
 * @param {boolean} [options.includeFunctionSerializer] An Boolean that
 *   indicates if the FunctionSerializer must be included. By default is false.
 * @returns {JsonSerializerAdapter} A new JsonSerializerAdapter object.
 */
declare function createJsonSerializerAdapter(options?: {
    includeFunctionSerializer?: boolean;
}): JsonSerializerAdapter;

export { createJsonSerializerAdapter };
